@@ -13,7 +13,9 @@ f_types = []
 F2_tallies = {'neutrons': [], 'photons': [], 'electrons': []}
 F4_tallies = {'neutrons': [], 'photons': [], 'electrons': []}
 F5_tallies = {'neutrons': [], 'photons': [], 'electrons': []}
+F6_tallies = {'neutrons': [], 'photons': [], 'electrons': [], 'Collision Heating': []}
 tally_types = {}
+fatal_errors = []
 warnings = []
 comments = []
 duplicate_surfaces = []
